==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/es.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Carga media",
    "Last minute" : "Último minuto",
    "Memory info not available" : "Información de la memoria no disponible",
    "Total" : "Total",
    "Current usage" : "Uso actual",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Links" : "Enlaces",
    "Federated sent" : "Federados enviados",
    "Federated received" : "Federados recibidos",
    "Last 24 hours" : "Últimas 24 horas",
    "Last 1 hour" : "Última hora",
    "Last 5 mins" : "Últimos 5 minutos",
    "Monitoring" : "Monitorizando",
    "CPU load" : "Carga del CPU",
    "Memory usage" : "Uso de memoria",
    "Active users" : "Usuarios activos",
    "Shares" : "Recursos compartidos",
    "Storage" : "Almacenamiento",
    "Users:" : "Usuarios:",
    "Files:" : "Archivos:",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory Limit:" : "Límite de memoria:",
    "Max Execution Time:" : "Máximo tiempo de ejecución:",
    "Upload max size:" : "Máximo tamaño de subida:",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "Size:" : "Tamaño:",
    "External monitoring tool" : "Herramienta de monitoreo externo",
    "You can connect an external monitoring tool by using this end point: " : "Puede conectar una herramienta externa de monitoreo usando este punto de comunicación:",
    "Server info" : "Información del servidor",
    "You can connect a external monitoring tool by using this end point: " : "Puedes conectar una herramienta de monitorización externa usando este punto de finalización:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/es.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Carga media",
    "Last minute" : "Último minuto",
    "Memory info not available" : "Información de la memoria no disponible",
    "Total" : "Total",
    "Current usage" : "Uso actual",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Links" : "Enlaces",
    "Federated sent" : "Federados enviados",
    "Federated received" : "Federados recibidos",
    "Last 24 hours" : "Últimas 24 horas",
    "Last 1 hour" : "Última hora",
    "Last 5 mins" : "Últimos 5 minutos",
    "Monitoring" : "Monitorización",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Provee información útil como la carga de la CPU, el uso de RAM y disco, el número de usuarios, etc.",
    "CPU load" : "Carga del CPU",
    "Memory usage" : "Uso de memoria",
    "Active users" : "Usuarios activos",
    "Shares" : "Recursos compartidos",
    "Storage" : "Almacenamiento",
    "Users:" : "Usuarios:",
    "Files:" : "Archivos:",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory Limit:" : "Límite de memoria:",
    "Max Execution Time:" : "Máximo tiempo de ejecución:",
    "Upload max size:" : "Máximo tamaño de subida:",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "Size:" : "Tamaño:",
    "External monitoring tool" : "Herramienta externa de monitorización",
    "You can connect an external monitoring tool by using this end point: " : "Puede conectar una herramienta externa de monitorización usando este punto de comunicación:"
},
"nplurals=2; plural=(n != 1);");
